@@ -144,7 +144,7 @@ class Appmenus(object):
         :return: True if target file was changed, otherwise False
         """
         if source.startswith('/'):
-            with open(source) as f_source:
+            with open(source, encoding='utf-8') as f_source:
                 source = f_source.read()
         if dispvm:
             if '\nX-Qubes-DispvmExec=' not in source and '\nExec=' in source:
@@ -163,11 +163,11 @@ class Appmenus(object):
             replace("%VMDIR%", os.path.join(basedir, vm.name)). \
             replace("%XDGICON%", icon)
         if os.path.exists(destination_path):
-            with open(destination_path) as dest_f:
+            with open(destination_path, encoding='utf-8') as dest_f:
                 current_dest = dest_f.read()
                 if current_dest == data:
                     return False
-        with open(destination_path, "w") as dest_f:
+        with open(destination_path, "w", encoding='utf-8') as dest_f:
             dest_f.write(data)
         return True
 
@@ -193,7 +193,7 @@ class Appmenus(object):
         # TODO icon path (#2885)
         for filename in self.get_available_filenames(vm, template):
             field_values = {}
-            with open(filename) as file:
+            with open(filename, encoding='utf-8') as file:
                 name = None
                 main_section = False
                 for line in file:
@@ -213,8 +213,8 @@ class Appmenus(object):
                             [x.strip() for x in line.split('=', 1)]
                         if field_name in fields:
                             field_values[field_name] = value
-            assert name is not None, \
-                'template {!r} does not contain name'.format(filename)
+            if name is None:
+                continue
             result = [os.path.basename(filename), name]
             if fields:
                 for field in fields:
@@ -353,7 +353,7 @@ class Appmenus(object):
             whitelist = vm.features['menu-items'].split(' ')
             appmenus = [x for x in appmenus if os.path.basename(x) in whitelist]
         elif os.path.exists(self.whitelist_path(vm)):
-            with open(self.whitelist_path(vm)) as whitelist_f:
+            with open(self.whitelist_path(vm), encoding='utf-8') as whitelist_f:
                 whitelist = [x.rstrip() for x in whitelist_f]
             appmenus = [x for x in appmenus if os.path.basename(x) in whitelist]
 
@@ -457,7 +457,8 @@ class Appmenus(object):
         """Return if a path to a desktop name is for the old menu version.
         """
         return not (name.startswith('org.qubes-os.') or
-                    name.startswith('qubes-vm-directory-'))
+                    name.startswith('qubes-vm-directory-') or
+                    name.startswith('qubes-dispvm-directory-'))
 
     def _old_directory_path(self, vm):
         """Return the old path of the directory file for this VM
@@ -514,7 +515,7 @@ class Appmenus(object):
         if 'menu-items' in vm.features:
             whitelist = vm.features['menu-items'].split(' ')
         elif os.path.exists(whitelist):
-            with open(whitelist) as whitelist_f:
+            with open(whitelist, encoding='utf-8') as whitelist_f:
                 whitelist = [line.strip() for line in whitelist_f]
         else:
             whitelist = None
@@ -641,6 +642,15 @@ class Appmenus(object):
         """
         vm.features['default-menu-items'] = ' '.join(applications_list)
 
+    @staticmethod
+    def get_default_whitelist(vm):
+        """
+        Get default applications list for VMs created on this template
+        :param vm: VM object
+        :return: list of applications in default whitelist
+        """
+        return vm.features.get('default-menu-items', '').split(' ')
+
     @staticmethod
     def set_whitelist(vm, applications_list):
         """Update list of applications to be included in the menu
@@ -665,7 +675,7 @@ class Appmenus(object):
             return None
         if not os.path.exists(self.whitelist_path(vm)):
             return None
-        with open(self.whitelist_path(vm), 'r') as whitelist:
+        with open(self.whitelist_path(vm), 'r', encoding='utf-8') as whitelist:
             for line in whitelist:
                 line = line.strip()
                 if not line:
@@ -727,6 +737,11 @@ parser_stdin_mode.add_argument(
     help='Set default list of applications to include in menu '
          'for VMs based on this template,'
          'use \'-\' to read from stdin')
+parser.add_argument(
+    '--get-default-whitelist', metavar='PATH',
+    help='Get default list of applications to include in menu '
+         'for VMs based on this template'
+)
 parser.add_argument(
     '--source', action='store', default=None,
     help='Source VM to copy data from (for --init option)')
@@ -763,7 +778,7 @@ def retrieve_list(path):
     """
     if path == '-':
         return [x.rstrip() for x in sys.stdin.readlines()]
-    with open(path, 'r') as file:
+    with open(path, 'r', encoding='utf-8') as file:
         return [x.rstrip() for x in file.readlines()]
 
 
@@ -812,6 +827,9 @@ def main(args=None, app=None):
             if args.set_default_whitelist:
                 whitelist = retrieve_list(args.set_default_whitelist)
                 appmenus.set_default_whitelist(vm, whitelist)
+            if args.get_default_whitelist:
+                default_whitelist = appmenus.get_default_whitelist(vm)
+                print('\n'.join(default_whitelist))
             if args.set_whitelist:
                 whitelist = retrieve_list(args.set_whitelist)
                 appmenus.set_whitelist(vm, whitelist)
